.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "3.1",
.\"     date            = "29 January 1996",
.\"     time            = "14:39:46 MST",
.\"     filename        = "chkdelim.man",
.\"     address         = "Center for Scientific Computing
.\"                        Department of Mathematics
.\"                        University of Utah
.\"                        Salt Lake City, UT 84112
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "55982 302 1198 9003",
.\"     email           = "beebe@math.utah.edu (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "delimiter check",
.\"     supported       = "yes",
.\"     docstring       = "This file contains the UNIX manual pages
.\"                        for chkdelim, the delimiter balance checking
.\"                        utility.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH CHKDELIM 1L "29 January 1996" "Version 3.1"
.if t .ds La L\\h'-0.24m'\\v'-0.15v'\\s-2A\\s+2\\h'-0.15m'\\v'0.15v'T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds La LaTeX
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.\"======================================================================
.SH "NAME"
chkdelim \- check delimiter balance
.\"======================================================================
.SH "SYNOPSIS"
.B chkdelim
[
.B \-?
]
[
.B \-author
]
[
.B \-copyright
]
[
.B \-help
]
.if n .ti +9n
[
.BI \-ignore " delimiters"
]
[
.B \-noparagraph
]
[
.B \-noTeX
]
.if t .ti +.5i
.if n .ti +9n
[
.B \-paragraph
]
[
.B \-TeX
]
.if t .ti +.5i
.if n .ti +9n
[
.B \-version
]
.if n .ti +9n
[
.IR "< infile" " or " " file1 file2 file3 .\|.\|."
]
.I "> outfile"
.\"=====================================================================
.SH DESCRIPTION
.B chkdelim
filters a list of files, or its standard input if
no filenames are provided, matching group
delimiters: angle brackets, curly braces,
parentheses, square brackets, forward quotes
(apostrophes or acutes), backward quotes (graves),
quotation marks, and dollar signs (used in the
\*(Te\& typesetting system).
.PP
Warning messages are printed to
.I stdout
whenever unbalanced delimiters are found, giving
the delimiter and its line, column, and file
positions.  The output format is recognizable by
the GNU
.B emacs
.I "M-x compile"
command, making it easy to parse the error
messages and jump to the error locations with the
keystrokes
.IR "C-x `" (next-error).
.PP
Dollar signs are checked only when the
.B \-TeX
option has been specified.  Single dollar signs
are expected to occur in pairs on the same line
for in-line math mode.  Doubled adjacent dollar
signs may be separated by several lines for
display-math mode.  However, if more than 10
lines, or a blank line, separate doubled dollar
signs, a warning is issued.
.PP
A backslash preceding a delimiter prevents it from
being recognized as a delimiter; this is a
suitable choice for \*(Te\& documents, as well as
for C-like programming languages and UNIX shells.
.PP
A backslash-asterisk pair preceding an open
parenthesis also prevents recognition of the
parenthesis.  This is suitable for
.B nroff
and
.B troff
two-letter user-defined macros, such as
.BR \e*(Te .
Such a character sequence is highly unlikely in
other files.
.PP
Checking of forward quotes (apostrophes) may be
less useful, because they are used both as string
delimiter characters in computer programming
languages, and in typewritten text, and also
singly, marking possessives or elided characters
in English-language text.  The
.B \-TeX
option described below implements a partial
workaround for this ambiguity.
.PP
If unbalanced delimiters are needed, it is often
possible to insert a matching delimiter in a
nearby comment so that the delimiter appears to
.B chkdelim
to be properly balanced.  This will reduce the
number of messages issued, so that the real errors
will be more evident.
.PP
.B chkdelim
is a handy tool for detecting common errors in
electronic documents and computer programs.
Its other purpose is to demonstrate a modest
.BR lex (1)
program.
.\"=====================================================================
.SH OPTIONS
Command-line switches may be abbreviated to a
unique leading prefix, and letter case is
.I not
significant.  Options affect only the processing
of files that
.I follow
them on the command line.  Should a file name
begin with a hyphen, you must protect it with a
directory path (e.g. ./) to prevent it from being
interpreted as a command-line option.
.\"-----------------------------------------------
.TP \w'\-ignoredelimiters'u+3n
.B \-?
Display a brief help message on
.IR stderr ,
and terminate.  Same as
.BR \-help .
.\"-----------------------------------------------
.TP
.B \-author
Display author information on
.IR stderr ,
and then continue processing.
.\"-----------------------------------------------
.TP
.B \-copyright
Display copyright information on
.IR stderr ,
and then continue processing.
.\"-----------------------------------------------
.TP
.B \-help
Display a brief help message on
.IR stderr ,
and terminate.  Same as
.BR \-? .
.\"-----------------------------------------------
.TP
.BI \-ignore " delimiters"
Forget the settings of any previous
.B \-ignore
option, and then specify one or more delimiter
characters that are to be ignored.  In the case of
paired delimiters (braces, brackets, parentheses),
either, or both, of a pair may be specified.
.IP
Since most delimiter characters have special
significance to command shells, it will usually be
necessary to protect them suitably from shell
interpretation, such as with backslashes, or
inside quoted strings.
.IP
Angle brackets are more commonly used for
less-than and greater-than symbols, rather than
<paired>, so
.BI \-ignore " \e<\e>"
will be a likely
.B chkdelim
option on UNIX systems.
.\"-----------------------------------------------
.TP
.BI \-noparagraph
Suppress any
.B \-paragraph
option specified earlier on the command line.
.\"-----------------------------------------------
.TP
.BI \-noTeX
Suppress any
.B \-TeX
option specified earlier on the command line.
.\"-----------------------------------------------
.TP
.BI \-paragraph
At end of paragraph, which is a line that is
empty, or contains only whitespace, issue any
needed error messages, and then forget any
delimiter imbalances.  This option is often useful
to limit the number of error messages that can
appear.
.\"-----------------------------------------------
.TP
.BI \-TeX
Check dollar signs in \*(Te\& files.  Without this
option, such characters are always ignored.
.IP
Also, check that forward and backward quotes
appear in open/close pairs: \&`.\|.\|.' and
\&``.\|.\|.'', instead of in the forms \&`.\|.\|.`
and \&'.\|.\|.' used in computer programming
languages.
.IP
Forward quotes between letters or digits are
ignored, so that possessives and elisions do not
raise bogus warnings.
.\"-----------------------------------------------
.TP
.B \-version
Display version information on
.IR stderr ,
and then continue processing.
.\"======================================================================
.SH BUGS
.B chkdelim
cannot detected improper nesting of delimiters,
such as in the string
.IR "( .\|.\|. [ .\|.\|. ) ]" .
.PP
In \*(Te\& documents, quotation marks ".\|.\|."
should be used only inside verbatim environments,
but
.B chkdelim
cannot recognize such environments, so it will
only warn if quotation marks are unbalanced.
\*(La\& users are advised to employ the
.BR lacheck (1)
utility to detect incorrect use of quotation
marks.
.\"======================================================================
.SH "SEE ALSO"
.BR awk (1),
.BR lacheck (1),
.BR lex (1).
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
Department of Mathematics
University of Utah
Salt Lake City, UT 84112
USA
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: beebe@math.utah.edu
WWW URL: http://www.math.utah.edu/~beebe
.fi
.\"==============================[The End]==============================
.\"=====================================================================
.\" This is for GNU Emacs file-specific customization:
.\" Local Variables:
.\" fill-column: 50
.\" End:
